@@ -4,7 +4,7 @@
  * Some editing types needed in the lib (unfortunately) for
  * scanfill.c
  *
- * $Id: BLI_editVert.h,v 1.6 2002/12/27 13:10:12 mein Exp $
+ * $Id: BLI_editVert.h,v 1.7 2003/11/19 22:00:12 ton Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -63,9 +63,7 @@ typedef struct EditVlak
 	struct EditVert *v1, *v2, *v3, *v4;
 	struct EditEdge *e1, *e2, *e3, *e4;
 	float n[3];
-	float uv[4][2];
-	unsigned int col[4];
-	struct TFace *tface;	/* a pointer to original tface. */
+	struct TFace tf;	/* a copy of original tface. */
 	unsigned char mat_nr, flag;
 	unsigned char f, f1;
 } EditVlak;
